@@ -29,3 +29,22 @@ class RetryException(Exception):
 
 class SiteNotResolvableException(Exception):
     pass
+
+
+class DuckDuckGoHasChangedException(Exception):
+    pass
+
+
+class StartPageHasChangedException(Exception):
+    pass
+
+
+class BingHasChangedException(Exception):
+    pass
+
+
+class WebDriverInitialisationException(Exception):
+    def __init__(self, e):
+        self.thrown_exception = e
+
+    pass
