@@ -4,14 +4,16 @@ import json
 import requests
 
 from exceptions import RetryException
-from services.rest_helper import RestHelper
+from logmgmt import logger
 from input.input_management import InputManager
 from model.process_type import ProcessType
+from services.rest_helper import RestHelper
 
 
 class RestClient:
     # region Path Variables
     # region Global, Tranco, Misc Paths
+    path_check_version = "/client/version.txt"
     path_check_token = "/rest/global/validateToken"
     path_tranco_entries_between = "/rest/tranco/between"
     path_get_tranco_id_for_site = "/rest/tranco/idforsite"
@@ -68,11 +70,19 @@ class RestClient:
             self.auth_bearer_header = {}
 
     # region Global, Tranco, Misc
+    def get_remote_client_version(self):
+        response = self.send_get_request(self.path_check_version)
+        if response.status_code == 200 and len(response.text) > 0:
+            return response.text.split("\n")[0]
+        logger.error(
+            "Something went wrong while checking version (" + str(response.status_code) + ") " + response.text)
+        return None
+
     def check_token(self, token):
         response = self.send_post_request(self.path_check_token, {'token': token})
         if response.status_code == 200 and response.text.startswith("valid"):
             return True
-        print("Something went wrong while checking (" + str(response.status_code) + "): " + response.text)
+        logger.error("Something went wrong while checking (" + str(response.status_code) + "): " + response.text)
         return False
 
     def get_list_of_tranco_domains(self, lower_bound, upper_bound):
@@ -80,7 +90,7 @@ class RestClient:
         response = requests.get(url, params={'lower': lower_bound, 'upper': upper_bound},
                                 headers=self.auth_bearer_header)
         if not response.status_code == 200:
-            print("Something went wrong (code " + str(response.status_code) + "): " + response.text)
+            logger.error("Something went wrong (code " + str(response.status_code) + "): " + response.text)
             return []
         return_list = []
         for entry in response.json():
@@ -91,7 +101,7 @@ class RestClient:
         response = self.send_get_request(self.path_get_tranco_id_for_site, {'site': site})
         if response.status_code == 200 and response.text.isnumeric():
             return response.text
-        print("Something went wrong")
+        logger.error("Something went wrong")
         return "UNKNOWN"
 
     def get_known_sso_provider(self):
@@ -149,16 +159,16 @@ class RestClient:
                      'findingstrategy': finding_strategy.name}
         response = self.send_post_request(self.path_add_new_login_page_location, post_data)
         if response.status_code == 200 and response.text.isnumeric():
-            print("Successfully saved login location!")
+            logger.info("Successfully saved login location!")
             if har_content is not None:
-                print("Uploading HAR file...")
+                logger.info("Uploading HAR file...")
                 if self.upload_har_files(response.text, har_content, ProcessType.LOGIN_PATH_DETECTION):
-                    print("Uploading HAR file finished!")
+                    logger.info("Uploading HAR file finished!")
             else:
-                print("No HAR content was given. Not going to upload har file!")
+                logger.info("No HAR content was given. Not going to upload har file!")
             return response.text
         else:
-            print("Something went wrong (code " + str(response.status_code) + ")")
+            logger.error("Something went wrong (code " + str(response.status_code) + ")")
             return False
 
     def get_additional_steps_for_login_path_location(self, login_path_detection_id):
@@ -167,57 +177,65 @@ class RestClient:
         return RestHelper.convert_json_to_list_of_additional_steps(response)
 
     def upload_har_files(self, saved_item_id, har_content, file_type):
-        print("Uploading har content")
+        logger.info("Uploading har content")
         if file_type == ProcessType.LOGIN_PATH_DETECTION:
             path = self.path_file_upload_login_path_detection
         else:
             raise Exception("Unknown har file type")
         response = self.send_post_file_request(path, {saved_item_id: base64.b64encode(har_content.encode("utf-8"))})
         if response.status_code == 200 and response.text == "success":
-            print("File uploaded successfully!")
+            logger.info("File uploaded successfully!")
             return True
         else:
-            print("Something went wrong (code " + str(response.status_code) + ")")
+            logger.error("Something went wrong (code " + str(response.status_code) + ")")
             return False
 
     def create_renew_login_location_request(self, page_id):
         response = self.send_post_request(self.path_create_login_location_renew_request, {"pageid": page_id})
         if response.status_code == 200:
             if response.text == "created":
-                print("Renew request created")
+                logger.info("Renew request created")
             elif response.text == "exists":
-                print("Renew request already exists")
+                logger.info("Renew request already exists")
             else:
-                print("Something went wrong!")
+                logger.error("Something went wrong!")
             return True
         else:
-            print("Something went wrong (code " + str(response.status_code) + ")")
+            logger.error("Something went wrong (code " + str(response.status_code) + ")")
             return False
 
     # endregion
 
     # region SSO Detection
-    def save_analysed_supported_sso_provider(self, trancosite, ids, analysis_session, results, har_content):
+    def save_analysed_supported_sso_provider(self, trancosite, ids, analysis_session, results, har_files):
+        transformed_ids = []
+        for id in ids:
+            tid = [id[0]]
+            if len(id) > 1:
+                tid.append(id[1]['x'])
+                tid.append(id[1]['y'])
+                tid.append(id[2])
+            transformed_ids.append(tid)
         post_data = {'analysisrunid': analysis_session, 'trancosite': trancosite,
-                     'supportedproviderids': ids, "loginpages": []}
+                     'supportedproviderids': transformed_ids, "loginpages": []}
         if results is not None:
             for result in results:
                 post_data['loginpages'].append(result['info'].loginPath)
         files = []
-        if har_content is not None:
-            files.append(('har', har_content))
+        if har_files is not None and len(har_files) > 0:
+            for har_file in har_files:
+                files.append(('har', har_file))
         if results is not None:
             for result in results:
                 files.append(('screenshot', result['screen']))
         if len(files) > 0:
-            print("Upload size of files (har, screen, ...): " + str(len(str(files)) * 0.000001) + " MB")
-        response = self.send_post_request_with_files(self.path_save_sso_analysis, post_data,
-                                                     files)
+            logger.info("Upload size of files (har, screen, ...): " + str(len(str(files)) * 0.000001) + " MB")
+        response = self.send_post_request_with_files(self.path_save_sso_analysis, post_data, files)
         if response.status_code == 200 and response.text == "success":
-            print("File uploaded successfully!")
+            logger.info("File uploaded successfully!")
             return True
         else:
-            print("Something went wrong (code " + str(response.status_code) + ")")
+            logger.error("Something went wrong (code " + str(response.status_code) + ")")
             return False
 
     def get_next_ssodetection_page_to_analyse_for_run(self, analysis_run_id):
@@ -239,10 +257,10 @@ class RestClient:
         response = self.send_post_request_with_files(self.path_save_privacy_detection, post_data,
                                                      files)
         if response.status_code == 200 and response.text == "success":
-            print("Privacy detection with HAR and Screenshot uploaded was successful!")
+            logger.info("Privacy detection with HAR and Screenshot uploaded was successful!")
             return True
         else:
-            print("Something went wrong (code " + str(response.status_code) + ")")
+            logger.error("Something went wrong (code " + str(response.status_code) + ")")
             return False
 
     def get_next_privacy_detection_page_to_analyse_for_run(self, analysis_run_id):
@@ -259,7 +277,7 @@ class RestClient:
                                           {'analysisrunid': analysisrunid, 'basepage': basepage, 'cause': cause})
         if response.status_code == 200:
             return True
-        print("Something went wrong (" + str(response.status_code) + ")!")
+        logger.error("Something went wrong (" + str(response.status_code) + ")!")
         return False
 
     def unregister_page_in_work(self, analysisrunid, basepage):
@@ -267,7 +285,7 @@ class RestClient:
                                           {'analysisrunid': analysisrunid, 'basepage': basepage})
         if response.status_code == 200:
             return True
-        print("Something went wrong (" + str(response.status_code) + ")!")
+        logger.error("Something went wrong (" + str(response.status_code) + ")!")
         return False
 
     def update_progress_of_analysis(self, analysisrunid: int, basepage: str, percent: int, status: str):
@@ -276,7 +294,7 @@ class RestClient:
                                            'percent': int(percent), 'status': status})
         if response.status_code == 200:
             return True
-        print("Something went wrong updating progress status (" + str(response.status_code) + ")!")
+        logger.error("Something went wrong updating progress status (" + str(response.status_code) + ")!")
         return False
 
     # endregion
@@ -291,7 +309,7 @@ class RestClient:
         response = self.send_get_request(self.path_get_analysis_run_type, {'analysisrunid': analysis_run_id})
         if response.status_code == 200 and response.text is not None and len(response.text) != 0:
             return response.text
-        print("Something went wrong (code " + str(response.status_code) + ")")
+        logger.error("Something went wrong (code " + str(response.status_code) + ")")
         return None
 
     def get_configuration_for_run(self, analysis_run_id):
@@ -314,9 +332,9 @@ class RestClient:
             else:
                 return None  # No more sites left!
         if response.status_code == 409:
-            print("Server requested a retry")
+            logger.info("Server requested a retry")
             raise RetryException()
-        print("Something went wrong (code " + str(response.status_code) + ")")
+        logger.error("Something went wrong (code " + str(response.status_code) + ")")
         return None
 
     def get_additional_analysis_run_information(self, analysis_run_id, key):
@@ -324,7 +342,7 @@ class RestClient:
                                          {'analysisrunid': analysis_run_id, 'key': key})
         if response.status_code == 200 and response.text is not None and len(response.text) != 0:
             return response.text
-        print("Something went wrong (code " + str(response.status_code) + ")")
+        logger.error("Something went wrong (code " + str(response.status_code) + ")")
         return None
 
     # endregion
@@ -338,7 +356,7 @@ class RestClient:
         if response.status_code == 200 and response.text is not None and len(response.text) != 0:
             return response.text
         elif response.status_code != 200:
-            print("Something went wrong! (code: " + str(response.status_code) + ")")
+            logger.error("Something went wrong! (code: " + str(response.status_code) + ")")
         return None
 
     def get_job_for_daemon_client(self):
@@ -368,7 +386,7 @@ class RestClient:
         return requests.post(self.url + path, data=postdata, headers=self.auth_bearer_header, allow_redirects=False)
 
     def send_post_file_request(self, path, files):
-        print("Size of fileupload: " + str(len(str(files)) * 0.000001) + " MB")
+        logger.info("Size of fileupload: " + str(len(str(files)) * 0.000001) + " MB")
         return requests.post(self.url + path, files=files, headers=self.auth_bearer_header, allow_redirects=False)
 
     def send_post_request_with_files(self, path, postdata, files):
